@@ -43,12 +43,31 @@ tutticolors=matrix(c(1,2,3,4,5,6,7,8,"rosybrown4", "green4", "navy", "purple2",
      for(i in 1:nrow(k)) {
       col=c(col, tutticolors[k[i,],])
      }
+if (ncol(P$scores) == 1) {
+  xlab = "Samples"
+  ylab = "Score values Component 1"
+  plot(P$scores[,1], col=col, pch=19, xlab=c(xlab), ylab=c(ylab), main = paste("PLS-DA Score Plot (", scaling, ")", sep=""))
+  lim1 = nrow(P$scores)*2
+  axis(1, at=c(-lim1,lim1), col="grey", pos=c(0,0), labels=FALSE, lwd=1)
+  text(P$scores[,1], col=col, cex=0.5, pos=1, labels=rownames(P$scores))
+  pwdout=paste(dirout, "ScorePlot_PLSDA_1Component_", scaling, ".pdf", sep="")
+  dev.copy2pdf(file=pwdout)
+  Max.pc2 = 1.1*(max(P$loadings[,1]))
+  Min.pc2 = 1.1*(min(P$loadings[,1]))
+  Mpc2=c(Min.pc2,Max.pc2)
+  dev.new()
+  plot(P$loadings[,1], ylim=Mpc2, main = paste("PLS-DA Loading Plot (", scaling, ")", sep=""), xlab="Variables", ylab="W*c values (Component1)")
+  text(P$loadings[,1], cex=0.7, pos=1, labels=rownames(P$loadings))
+  pwdout1=paste(dirout, "W*cPlot_PLSDA_1Component_", scaling, ".pdf", sep="")
+  dev.copy2pdf(file=pwdout1)
+} else {
 pairs = c()
      if (ncol(P$scores) >= 10) {pairs = c(10)} else {pairs = c(ncol(P$scores))}
 
      pairs(P$scores[,1:pairs],col=col)
      pairs = paste(dirout, "Pairs_PLSDA_", scaling, ".pdf", sep="")
      dev.copy2pdf(file=pairs)
+}
 p.v = matrix(P$Xvar, ncol=1)
 	p.v.out = paste(dirout, "PLSDA_P_", scaling, ".out", sep="")
 	write.csv(p.v, file=p.v.out)
